# Views

Views are the components that make up most of the user interface. They go in the Side Bar and the Panel panes. They are responsible for displaying the content of the application.

The built-in views that come with Biscuit are:
|Name|Purpose|
|---|---|
|`Explorer`|Displays the file explorer.|
|`Output`|Displays the output of commands and tasks.|
|`Search`|Displays the search results.|
|`SourceControl`|Displays the source control status.|
|`Debug`|Displays the debug console.|
|`Extensions`|Displays the extensions installed.|
|`GitHub`|Displays the GitHub repository.|
|`AI`|Displays the AI assistant.|
|`TerminalView`|Displays the terminal.|
|`Logs`|Displays the logs.|
|`Problems`|Displays the problems in the workspace.|
